pub enum MaybeMultiConfig {
Split {
config: Option<Config>,
config_alt: Option<Config>,
},
Multiple {
configs: Vec<Config>,
},
}Expand description
The MaybeMultiConfig type is used to represent a configuration that can either be a single Config or multiple Configs.
Note: An empty list of configs is not allowed
It is used to support different ways of specifying formats in the configuration file:
- A single format:
[[block]]
block = "xxx"
format = "{layout}"- A format and an alternative format:
[[block]]
block = "xxx"
format = "{layout}"
format_alt = "{layout^2}"- A list of formats:
[[block]]
block = "xxx"
format = ["{layout}"]- A single format with full and short variants:
[[block]]
block = "xxx"
[block.format]
full = "{layout}"
short = "{layout^2}"- A format and an alternative format with full and short variants:
[[block]]
block = "xxx"
[block.format]
full = "{layout}"
short = "{layout^2}"
[block.format_alt]
full = "{layout^3}"
short = "{layout^4}"- A list of formats with full and short variants:
[[block]]
block = "xxx"
[[block.format]]
full = "{layout}"
short = "{layout^2}"Variants
Implementations
Sourceimpl MaybeMultiConfig
impl MaybeMultiConfig
pub fn with_default(&self, default_full: &str) -> Result<MultiFormat>
pub fn with_defaults( &self, default_full: &str, default_short: &str, ) -> Result<MultiFormat>
pub fn with_default_formats(&self, default_formats: &[Format]) -> MultiFormat